==> zouba_0.4.tar.gz: zouba-0.4/src/gpscontroller_p.cpp <==
#include "gpscontroller_p.h"

#include "location.h"

#include <QObject>
#include <QGeoPositionInfo>
#include <QGeoPositionInfoSource>
#include <QDebug>

QTM_USE_NAMESPACE

GpsControllerPrivate::GpsControllerPrivate() :
  m_gps(0),
  m_currentLocation(0),
  m_useFakeLocation(false)
{
}

GpsControllerPrivate::~GpsControllerPrivate()
{
  delete m_gps;
  m_gps = 0;
  delete m_currentLocation;
  m_currentLocation = 0;
}

void GpsControllerPrivate::init()
{
  m_gps = QGeoPositionInfoSource::createDefaultSource(this);
  connect(
      m_gps, SIGNAL( positionUpdated( QGeoPositionInfo ) ),
      this, SLOT( updateLocation( QGeoPositionInfo ) )
  );
}

void GpsControllerPrivate::startGps()
{
  m_gps->startUpdates();
}

void GpsControllerPrivate::stopGps()
{
  m_gps->stopUpdates();
}

QGeoPositionInfoSource *GpsControllerPrivate::gps()
{
  return m_gps;
}

void GpsControllerPrivate::setGps( QGeoPositionInfoSource *gps )
{
  m_gps = gps;
}

Location *GpsControllerPrivate::currentLocation()
{
  return m_currentLocation;
}

void GpsControllerPrivate::setCurrentLocation( Location *location )
{
  delete m_currentLocation;
  m_currentLocation = location;
}

bool GpsControllerPrivate::useFakeLocation()
{
  return m_useFakeLocation;
}

void GpsControllerPrivate::setUseFakeLocation( bool useFake )
{
  m_useFakeLocation = useFake;
}

void GpsControllerPrivate::updateLocation( QGeoPositionInfo positionInfo )
{
  if ( !m_useFakeLocation ) {
    delete m_currentLocation;
    m_currentLocation = new Location( positionInfo );
  }
}

==> zouba_0.6.tar.gz: zouba-0.6/src/gpscontroller_p.cpp <==
#include "gpscontroller_p.h"

#include "location.h"

#include <QObject>
#include <QGeoPositionInfo>
#include <QGeoPositionInfoSource>
#include <QDebug>

QTM_USE_NAMESPACE

GpsControllerPrivate::GpsControllerPrivate() :
  m_gps(0),
  m_currentLocation(0),
  m_useFakeLocation(false)
{
}

GpsControllerPrivate::~GpsControllerPrivate()
{
  delete m_gps;
  m_gps = 0;
  delete m_currentLocation;
  m_currentLocation = 0;
}

void GpsControllerPrivate::init()
{
  m_gps = QGeoPositionInfoSource::createDefaultSource(this);
  connect(
      m_gps, SIGNAL( positionUpdated( QGeoPositionInfo ) ),
      this, SLOT( updateLocation( QGeoPositionInfo ) )
  );
}

void GpsControllerPrivate::startGps()
{
  m_gps->startUpdates();
}

void GpsControllerPrivate::stopGps()
{
  m_gps->stopUpdates();
}

QGeoPositionInfoSource *GpsControllerPrivate::gps()
{
  return m_gps;
}

void GpsControllerPrivate::setGps( QGeoPositionInfoSource *gps )
{
  m_gps = gps;
}

Location *GpsControllerPrivate::currentLocation()
{
  return m_currentLocation;
}

void GpsControllerPrivate::setCurrentLocation( Location *location )
{
  if ( m_currentLocation && m_currentLocation->label() == "livegps" ) {
    delete m_currentLocation;
    m_currentLocation=0;
  }
  m_currentLocation = location;
}

bool GpsControllerPrivate::useFakeLocation()
{
  return m_useFakeLocation;
}

void GpsControllerPrivate::setUseFakeLocation( bool useFake )
{
  // delete previous GPS if it was live and we're switching to fake
  if ( m_currentLocation && m_currentLocation->label() == "livegps" ) {
    delete m_currentLocation;
    m_currentLocation = 0;
  }
  m_useFakeLocation = useFake;
}

void GpsControllerPrivate::updateLocation( QGeoPositionInfo positionInfo )
{
  if ( m_currentLocation && m_currentLocation->label() == "livegps" ) {
    delete m_currentLocation;
  }
  m_currentLocation = new Location( positionInfo, "livegps" );
}
